==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/ProbeFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProbeFluent<A extends io.fabric8.kubernetes.api.model.ProbeFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ExecAction getExec();
  public io.fabric8.kubernetes.api.model.ExecAction buildExec();
  public A withExec(io.fabric8.kubernetes.api.model.ExecAction exec);
  public java.lang.Boolean hasExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> withNewExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> withNewExecLike(io.fabric8.kubernetes.api.model.ExecAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editOrNewExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editOrNewExecLike(io.fabric8.kubernetes.api.model.ExecAction item);
  public java.lang.Integer getFailureThreshold();
  public A withFailureThreshold(java.lang.Integer failureThreshold);
  public java.lang.Boolean hasFailureThreshold();
  
  /**
   * This method has been deprecated, please use method buildHttpGet instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.HTTPGetAction getHttpGet();
  public io.fabric8.kubernetes.api.model.HTTPGetAction buildHttpGet();
  public A withHttpGet(io.fabric8.kubernetes.api.model.HTTPGetAction httpGet);
  public java.lang.Boolean hasHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> withNewHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> withNewHttpGetLike(io.fabric8.kubernetes.api.model.HTTPGetAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editOrNewHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editOrNewHttpGetLike(io.fabric8.kubernetes.api.model.HTTPGetAction item);
  public java.lang.Integer getInitialDelaySeconds();
  public A withInitialDelaySeconds(java.lang.Integer initialDelaySeconds);
  public java.lang.Boolean hasInitialDelaySeconds();
  public java.lang.Integer getPeriodSeconds();
  public A withPeriodSeconds(java.lang.Integer periodSeconds);
  public java.lang.Boolean hasPeriodSeconds();
  public java.lang.Integer getSuccessThreshold();
  public A withSuccessThreshold(java.lang.Integer successThreshold);
  public java.lang.Boolean hasSuccessThreshold();
  
  /**
   * This method has been deprecated, please use method buildTcpSocket instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.TCPSocketAction getTcpSocket();
  public io.fabric8.kubernetes.api.model.TCPSocketAction buildTcpSocket();
  public A withTcpSocket(io.fabric8.kubernetes.api.model.TCPSocketAction tcpSocket);
  public java.lang.Boolean hasTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> withNewTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> withNewTcpSocketLike(io.fabric8.kubernetes.api.model.TCPSocketAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editOrNewTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editOrNewTcpSocketLike(io.fabric8.kubernetes.api.model.TCPSocketAction item);
  public java.lang.Long getTerminationGracePeriodSeconds();
  public A withTerminationGracePeriodSeconds(java.lang.Long terminationGracePeriodSeconds);
  public java.lang.Boolean hasTerminationGracePeriodSeconds();
  public java.lang.Integer getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Integer timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public interface ExecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<N>>{
    public N and();
    public N endExec();
    
  }
  public interface HttpGetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.HTTPGetActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<N>>{
    public N and();
    public N endHttpGet();
    
  }
  public interface TcpSocketNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.TCPSocketActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<N>>{
    public N and();
    public N endTcpSocket();
    
  }
  
}

==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/ProbeFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProbeFluent<A extends io.fabric8.kubernetes.api.model.ProbeFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildExec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ExecAction getExec();
  public io.fabric8.kubernetes.api.model.ExecAction buildExec();
  public A withExec(io.fabric8.kubernetes.api.model.ExecAction exec);
  public java.lang.Boolean hasExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> withNewExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> withNewExecLike(io.fabric8.kubernetes.api.model.ExecAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editOrNewExec();
  public io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<A> editOrNewExecLike(io.fabric8.kubernetes.api.model.ExecAction item);
  public java.lang.Integer getFailureThreshold();
  public A withFailureThreshold(java.lang.Integer failureThreshold);
  public java.lang.Boolean hasFailureThreshold();
  
  /**
   * This method has been deprecated, please use method buildHttpGet instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.HTTPGetAction getHttpGet();
  public io.fabric8.kubernetes.api.model.HTTPGetAction buildHttpGet();
  public A withHttpGet(io.fabric8.kubernetes.api.model.HTTPGetAction httpGet);
  public java.lang.Boolean hasHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> withNewHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> withNewHttpGetLike(io.fabric8.kubernetes.api.model.HTTPGetAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editOrNewHttpGet();
  public io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<A> editOrNewHttpGetLike(io.fabric8.kubernetes.api.model.HTTPGetAction item);
  public java.lang.Integer getInitialDelaySeconds();
  public A withInitialDelaySeconds(java.lang.Integer initialDelaySeconds);
  public java.lang.Boolean hasInitialDelaySeconds();
  public java.lang.Integer getPeriodSeconds();
  public A withPeriodSeconds(java.lang.Integer periodSeconds);
  public java.lang.Boolean hasPeriodSeconds();
  public java.lang.Integer getSuccessThreshold();
  public A withSuccessThreshold(java.lang.Integer successThreshold);
  public java.lang.Boolean hasSuccessThreshold();
  
  /**
   * This method has been deprecated, please use method buildTcpSocket instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.TCPSocketAction getTcpSocket();
  public io.fabric8.kubernetes.api.model.TCPSocketAction buildTcpSocket();
  public A withTcpSocket(io.fabric8.kubernetes.api.model.TCPSocketAction tcpSocket);
  public java.lang.Boolean hasTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> withNewTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> withNewTcpSocketLike(io.fabric8.kubernetes.api.model.TCPSocketAction item);
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editOrNewTcpSocket();
  public io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<A> editOrNewTcpSocketLike(io.fabric8.kubernetes.api.model.TCPSocketAction item);
  public java.lang.Long getTerminationGracePeriodSeconds();
  public A withTerminationGracePeriodSeconds(java.lang.Long terminationGracePeriodSeconds);
  public java.lang.Boolean hasTerminationGracePeriodSeconds();
  public java.lang.Integer getTimeoutSeconds();
  public A withTimeoutSeconds(java.lang.Integer timeoutSeconds);
  public java.lang.Boolean hasTimeoutSeconds();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ExecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ExecActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.ExecNested<N>>{
    public N and();
    public N endExec();
    
  }
  public interface HttpGetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.HTTPGetActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.HttpGetNested<N>>{
    public N and();
    public N endHttpGet();
    
  }
  public interface TcpSocketNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.TCPSocketActionFluent<io.fabric8.kubernetes.api.model.ProbeFluent.TcpSocketNested<N>>{
    public N and();
    public N endTcpSocket();
    
  }
  
}
